@@ -18,26 +18,17 @@
 #include "neochatroom.h"
 #include "utils.h"
 
+#include "testutils.h"
+
 using namespace Quotient;
 
-class TestRoom : public NeoChatRoom
-{
-public:
-    using NeoChatRoom::NeoChatRoom;
-
-    void update(SyncRoomData &&data, bool fromCache = false)
-    {
-        Room::updateData(std::move(data), fromCache);
-    }
-};
-
 class EventHandlerTest : public QObject
 {
     Q_OBJECT
 
 private:
     Connection *connection = nullptr;
-    TestRoom *room = nullptr;
+    TestUtils::TestRoom *room = nullptr;
     EventHandler eventHandler;
     EventHandler emptyHandler;
     EventHandler noEventHandler;
@@ -70,6 +61,8 @@ private Q_SLOTS:
     void genericBody_data();
     void genericBody();
     void nullGenericBody();
+    void subtitle();
+    void nullSubtitle();
     void mediaInfo();
     void nullMediaInfo();
     void linkPreviewer();
@@ -101,14 +94,7 @@ private Q_SLOTS:
 void EventHandlerTest::initTestCase()
 {
     connection = Connection::makeMockConnection(QStringLiteral("@bob:kde.org"));
-    room = new TestRoom(connection, QStringLiteral("#myroom:kde.org"), JoinState::Join);
-
-    QFile testEventHandlerSyncFile;
-    testEventHandlerSyncFile.setFileName(QLatin1String(DATA_DIR) + u'/' + QLatin1String("test-eventhandler-sync.json"));
-    testEventHandlerSyncFile.open(QIODevice::ReadOnly);
-    const auto testEventHandlerSyncJson = QJsonDocument::fromJson(testEventHandlerSyncFile.readAll());
-    SyncRoomData roomData(QStringLiteral("@bob:kde.org"), JoinState::Join, testEventHandlerSyncJson.object());
-    room->update(std::move(roomData));
+    room = new TestUtils::TestRoom(connection, QStringLiteral("#myroom:kde.org"), QLatin1String("test-eventhandler-sync.json"));
 
     eventHandler.setRoom(room);
     noEventHandler.setRoom(room);
@@ -364,6 +350,25 @@ void EventHandlerTest::nullGenericBody()
     QCOMPARE(noEventHandler.getGenericBody(), QString());
 }
 
+void EventHandlerTest::subtitle()
+{
+    auto event = room->messageEvents().at(0).get();
+    eventHandler.setEvent(event);
+
+    QCOMPARE(eventHandler.subtitleText(), QStringLiteral("after: This is an example text message"));
+
+    event = room->messageEvents().at(2).get();
+    eventHandler.setEvent(event);
+
+    QCOMPARE(eventHandler.subtitleText(), QStringLiteral("after: This is a highlight @bob:kde.org and this is a link https://kde.org"));
+}
+
+void EventHandlerTest::nullSubtitle()
+{
+    QTest::ignoreMessage(QtWarningMsg, "subtitleText called with m_event set to nullptr.");
+    QCOMPARE(noEventHandler.subtitleText(), QString());
+}
+
 void EventHandlerTest::mediaInfo()
 {
     auto event = room->messageEvents().at(4).get();
