@@ -10,28 +10,21 @@
 #include <Quotient/syncdata.h>
 #include <qnamespace.h>
 
+#include "models/customemojimodel.h"
+#include "neochatconnection.h"
 #include "utils.h"
 
+#include "testutils.h"
+
 using namespace Quotient;
 
-class TestRoom : public NeoChatRoom
-{
-public:
-    using NeoChatRoom::NeoChatRoom;
-
-    void update(SyncRoomData &&data, bool fromCache = false)
-    {
-        Room::updateData(std::move(data), fromCache);
-    }
-};
-
 class TextHandlerTest : public QObject
 {
     Q_OBJECT
 
 private:
     Connection *connection = nullptr;
-    TestRoom *room = nullptr;
+    TestUtils::TestRoom *room = nullptr;
 
 private Q_SLOTS:
     void initTestCase();
@@ -48,6 +41,9 @@ private Q_SLOTS:
     void sendBadLinks();
     void sendEscapeCode();
     void sendCodeClass();
+    void sendCustomEmoji();
+    void sendCustomEmojiCode_data();
+    void sendCustomEmojiCode();
 
     void receiveStripReply();
     void receivePlainTextIn();
@@ -78,14 +74,15 @@ private Q_SLOTS:
 void TextHandlerTest::initTestCase()
 {
     connection = Connection::makeMockConnection(QStringLiteral("@bob:kde.org"));
-    room = new TestRoom(connection, QStringLiteral("#myroom:kde.org"), JoinState::Join);
+    connection->setAccountData("im.ponies.user_emotes"_ls,
+                               QJsonObject{{"images"_ls,
+                                            QJsonObject{{"test"_ls,
+                                                         QJsonObject{{"body"_ls, "Test custom emoji"_ls},
+                                                                     {"url"_ls, "mxc://example.org/test"_ls},
+                                                                     {"usage"_ls, QJsonArray{"emoticon"_ls}}}}}}});
+    CustomEmojiModel::instance().setConnection(static_cast<NeoChatConnection *>(connection));
 
-    QFile testTextHandlerSyncFile;
-    testTextHandlerSyncFile.setFileName(QLatin1String(DATA_DIR) + u'/' + QLatin1String("test-texthandler-sync.json"));
-    testTextHandlerSyncFile.open(QIODevice::ReadOnly);
-    const auto testTextHandlerSyncJson = QJsonDocument::fromJson(testTextHandlerSyncFile.readAll());
-    SyncRoomData roomData(QStringLiteral("@bob:kde.org"), JoinState::Join, testTextHandlerSyncJson.object());
-    room->update(std::move(roomData));
+    room = new TestUtils::TestRoom(connection, QStringLiteral("#myroom:kde.org"), QLatin1String("test-texthandler-sync.json"));
 }
 
 void TextHandlerTest::allowedAttributes()
@@ -234,6 +231,39 @@ void TextHandlerTest::sendCodeClass()
     QCOMPARE(testTextHandler.handleSendText(), testOutputString);
 }
 
+void TextHandlerTest::sendCustomEmoji()
+{
+    const QString testInputString = QStringLiteral(":test:");
+    const QString testOutputString = QStringLiteral(
+        "<p><img data-mx-emoticon=\"\" src=\"mxc://example.org/test\" alt=\":test:\" title=\":test:\" height=\"32\" vertical-align=\"middle\" /></p>");
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.handleSendText(), testOutputString);
+}
+
+void TextHandlerTest::sendCustomEmojiCode_data()
+{
+    QTest::addColumn<QString>("testInputString");
+    QTest::addColumn<QString>("testOutputString");
+
+    QTest::newRow("inline") << QStringLiteral("`:test:`") << QStringLiteral("<p><code>:test:</code></p>");
+    QTest::newRow("block") << QStringLiteral("```\n:test:\n```") << QStringLiteral("<pre><code>:test:\n</code></pre>");
+}
+
+// Custom emojis in code blocks should be left alone.
+void TextHandlerTest::sendCustomEmojiCode()
+{
+    QFETCH(QString, testInputString);
+    QFETCH(QString, testOutputString);
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.handleSendText(), testOutputString);
+}
+
 void TextHandlerTest::receiveStripReply()
 {
     const QString testInputString = QStringLiteral(
