@@ -181,7 +181,7 @@ QString EventHandler::singleLineAuthorDisplayname(bool isPending) const
     }
 
     const auto author = isPending ? m_room->localUser() : m_room->user(m_event->senderId());
-    auto displayName = m_room->htmlSafeMemberName(author->id());
+    auto displayName = m_room->safeMemberName(author->id());
     displayName.replace(QStringLiteral("<br>\n"), QStringLiteral(" "));
     displayName.replace(QStringLiteral("<br>"), QStringLiteral(" "));
     displayName.replace(QStringLiteral("<br />\n"), QStringLiteral(" "));
@@ -645,6 +645,15 @@ QString EventHandler::getGenericBody() const
         i18n("Unknown event"));
 }
 
+QString EventHandler::subtitleText() const
+{
+    if (m_event == nullptr) {
+        qCWarning(EventHandling) << "subtitleText called with m_event set to nullptr.";
+        return {};
+    }
+    return singleLineAuthorDisplayname() + (m_event->isStateEvent() ? QLatin1String(" ") : QLatin1String(": ")) + getPlainBody(true);
+}
+
 QVariantMap EventHandler::getMediaInfo() const
 {
     if (m_room == nullptr) {
