@@ -8,17 +8,22 @@
 #include <Quotient/connection.h>
 #include <Quotient/csapi/content-repo.h>
 
+#include "neochatconfig.h"
 #include "neochatroom.h"
 
 using namespace Quotient;
 
-LinkPreviewer::LinkPreviewer(QObject *parent, NeoChatRoom *room, const QUrl &url)
+LinkPreviewer::LinkPreviewer(QObject *parent, const NeoChatRoom *room, const QUrl &url)
     : QObject(parent)
     , m_currentRoom(room)
     , m_loaded(false)
     , m_url(url)
 {
     loadUrlPreview();
+    if (m_currentRoom) {
+        connect(m_currentRoom, &NeoChatRoom::urlPreviewEnabledChanged, this, &LinkPreviewer::loadUrlPreview);
+    }
+    connect(NeoChatConfig::self(), &NeoChatConfig::ShowLinkPreviewChanged, this, &LinkPreviewer::loadUrlPreview);
 }
 
 bool LinkPreviewer::loaded() const
@@ -57,19 +62,22 @@ void LinkPreviewer::setUrl(QUrl url)
 
 void LinkPreviewer::loadUrlPreview()
 {
+    if (!m_currentRoom || !NeoChatConfig::showLinkPreview() || !m_currentRoom->urlPreviewEnabled()) {
+        return;
+    }
     if (m_url.scheme() == QStringLiteral("https")) {
         m_loaded = false;
         Q_EMIT loadedChanged();
 
         auto conn = m_currentRoom->connection();
-        GetUrlPreviewJob *job = conn->callApi<GetUrlPreviewJob>(m_url.toString());
+        GetUrlPreviewJob *job = conn->callApi<GetUrlPreviewJob>(m_url);
 
         connect(job, &BaseJob::success, this, [this, job, conn]() {
             const auto json = job->jsonData();
-            m_title = json["og:title"].toString().trimmed();
-            m_description = json["og:description"].toString().trimmed().replace("\n", " ");
+            m_title = json["og:title"_ls].toString().trimmed();
+            m_description = json["og:description"_ls].toString().trimmed().replace("\n"_ls, " "_ls);
 
-            auto imageUrl = QUrl(json["og:image"].toString());
+            auto imageUrl = QUrl(json["og:image"_ls].toString());
             if (imageUrl.isValid() && imageUrl.scheme() == QStringLiteral("mxc")) {
                 m_imageSource = conn->makeMediaUrl(imageUrl);
             } else {
@@ -85,4 +93,9 @@ void LinkPreviewer::loadUrlPreview()
     }
 }
 
+bool LinkPreviewer::empty() const
+{
+    return m_url.isEmpty();
+}
+
 #include "moc_linkpreviewer.cpp"
