@@ -188,22 +188,14 @@ QHash<int, QByteArray> CustomEmojiModel::roleNames() const
     };
 }
 
-QString CustomEmojiModel::preprocessText(const QString &text)
+QString CustomEmojiModel::preprocessText(QString text)
 {
-    auto parts = text.split("```"_ls);
-    bool skip = true;
-    for (auto &part : parts) {
-        skip = !skip;
-        if (skip) {
-            continue;
-        }
-        for (const auto &emoji : std::as_const(m_emojis)) {
-            part.replace(
-                emoji.regexp,
-                QStringLiteral(R"(<img data-mx-emoticon="" src="%1" alt="%2" title="%2" height="32" vertical-align="middle" />)").arg(emoji.url, emoji.name));
-        }
+    for (const auto &emoji : std::as_const(m_emojis)) {
+        text.replace(
+            emoji.regexp,
+            QStringLiteral(R"(<img data-mx-emoticon="" src="%1" alt="%2" title="%2" height="32" vertical-align="middle" />)").arg(emoji.url, emoji.name));
     }
-    return parts.join("```"_ls);
+    return text;
 }
 
 QVariantList CustomEmojiModel::filterModel(const QString &filter)
