@@ -5,6 +5,7 @@
 
 #include <QAbstractListModel>
 #include <QObject>
+#include <QQmlEngine>
 
 #include <Quotient/csapi/list_public_rooms.h>
 
@@ -27,6 +28,7 @@ class Connection;
 class PublicRoomListModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
     /**
      * @brief The current connection that the model is getting its rooms from.
@@ -43,20 +45,30 @@ class PublicRoomListModel : public QAbstractListModel
      */
     Q_PROPERTY(QString keyword READ keyword WRITE setKeyword NOTIFY keywordChanged)
 
+    /**
+     * @brief Whether only space rooms should be shown.
+     */
+    Q_PROPERTY(bool showOnlySpaces READ showOnlySpaces WRITE setShowOnlySpaces NOTIFY showOnlySpacesChanged)
+
     /**
      * @brief Whether the model has more items to load.
      */
     Q_PROPERTY(bool hasMore READ hasMore NOTIFY hasMoreChanged)
 
+    /**
+     * @biref Whether the model is still loading.
+     */
+    Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
+
 public:
     /**
      * @brief Defines the model roles.
      */
     enum EventRoles {
-        NameRole = Qt::DisplayRole + 1, /**< The name of the room. */
-        AvatarRole, /**< The source URL for the room's avatar. */
+        DisplayNameRole = Qt::DisplayRole + 1, /**< The name of the room. */
+        AvatarUrlRole, /**< The source URL for the room's avatar. */
         TopicRole, /**< The room topic. */
-        RoomIDRole, /**< The room matrix ID. */
+        RoomIdRole, /**< The room matrix ID. */
         AliasRole, /**< The room canonical alias. */
         MemberCountRole, /**< The number of members in the room. */
         AllowGuestsRole, /**< Whether the room allows guest users. */
@@ -71,7 +83,7 @@ public:
      *
      * @sa QAbstractItemModel::data
      */
-    [[nodiscard]] QVariant data(const QModelIndex &index, int role = NameRole) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = DisplayNameRole) const override;
 
     /**
      * @brief Number of rows in the model.
@@ -96,8 +108,13 @@ public:
     [[nodiscard]] QString keyword() const;
     void setKeyword(const QString &value);
 
+    [[nodiscard]] bool showOnlySpaces() const;
+    void setShowOnlySpaces(bool showOnlySpaces);
+
     [[nodiscard]] bool hasMore() const;
 
+    [[nodiscard]] bool loading() const;
+
     /**
      * @brief Load the next set of rooms.
      *
@@ -109,11 +126,13 @@ private:
     Quotient::Connection *m_connection = nullptr;
     QString m_server;
     QString m_keyword;
+    bool m_showOnlySpaces = false;
 
     bool attempted = false;
+    bool m_loading = false;
     QString nextBatch;
 
-    QVector<Quotient::PublicRoomsChunk> rooms;
+    QList<Quotient::PublicRoomsChunk> rooms;
 
     Quotient::QueryPublicRoomsJob *job = nullptr;
 
@@ -121,5 +140,7 @@ Q_SIGNALS:
     void connectionChanged();
     void serverChanged();
     void keywordChanged();
+    void showOnlySpacesChanged();
     void hasMoreChanged();
+    void loadingChanged();
 };
