@@ -4,6 +4,7 @@
 #include "roomlistmodel.h"
 
 #include "controller.h"
+#include "eventhandler.h"
 #include "neochatconfig.h"
 #include "neochatroom.h"
 #include "roommanager.h"
@@ -174,10 +175,10 @@ void RoomListModel::connectRoomSignals(NeoChatRoom *room)
         refresh(room);
     });
     connect(room, &Room::addedMessages, this, [this, room] {
-        refresh(room, {LastEventRole, SubtitleTextRole, LastActiveTimeRole});
+        refresh(room, {SubtitleTextRole, LastActiveTimeRole});
     });
     connect(room, &Room::pendingEventMerged, this, [this, room] {
-        refresh(room, {LastEventRole, SubtitleTextRole});
+        refresh(room, {SubtitleTextRole});
     });
     connect(room, &Room::unreadStatsChanged, this, &RoomListModel::refreshNotificationCount);
     connect(room, &Room::highlightCountChanged, this, &RoomListModel::refreshHighlightCount);
@@ -332,12 +333,6 @@ QVariant RoomListModel::data(const QModelIndex &index, int role) const
     if (role == HighlightCountRole) {
         return room->highlightCount();
     }
-    if (role == LastEventRole) {
-        if (room->lastEventIsSpoiler()) {
-            return QString();
-        }
-        return room->lastEventToString();
-    }
     if (role == LastActiveTimeRole) {
         return room->lastActiveTime();
     }
@@ -354,7 +349,13 @@ QVariant RoomListModel::data(const QModelIndex &index, int role) const
         return m_categoryVisibility.value(data(index, CategoryRole).toInt(), true);
     }
     if (role == SubtitleTextRole) {
-        return room->lastEventToString(Qt::PlainText, true);
+        if (room->lastEventIsSpoiler()) {
+            return QString();
+        }
+        EventHandler eventHandler;
+        eventHandler.setRoom(room);
+        eventHandler.setEvent(room->lastEvent());
+        return eventHandler.subtitleText();
     }
     if (role == AvatarImageRole) {
         return room->avatar(128);
@@ -396,7 +397,6 @@ QHash<int, QByteArray> RoomListModel::roleNames() const
     roles[CategoryRole] = "category";
     roles[NotificationCountRole] = "notificationCount";
     roles[HighlightCountRole] = "highlightCount";
-    roles[LastEventRole] = "lastEvent";
     roles[LastActiveTimeRole] = "lastActiveTime";
     roles[JoinStateRole] = "joinState";
     roles[CurrentRoomRole] = "currentRoom";
