@@ -124,12 +124,11 @@ void NeoChatConnection::changePassword(const QString &currentPassword, const QSt
             QJsonObject identifier = {{"type"_ls, "m.id.user"_ls}, {"user"_ls, user()->id()}};
             authData["identifier"_ls] = identifier;
             NeochatChangePasswordJob *innerJob = callApi<NeochatChangePasswordJob>(newPassword, false, authData);
-            connect(innerJob, &BaseJob::success, this, []() {
-                Q_EMIT Controller::instance().passwordStatus(Controller::PasswordStatus::Success);
+            connect(innerJob, &BaseJob::success, this, [this]() {
+                Q_EMIT passwordStatus(PasswordStatus::Success);
             });
-            connect(innerJob, &BaseJob::failure, this, [innerJob]() {
-                Q_EMIT Controller::instance().passwordStatus(innerJob->jsonData()["errcode"_ls] == "M_FORBIDDEN"_ls ? Controller::PasswordStatus::Wrong
-                                                                                                                    : Controller::PasswordStatus::Other);
+            connect(innerJob, &BaseJob::failure, this, [innerJob, this]() {
+                Q_EMIT passwordStatus(innerJob->jsonData()["errcode"_ls] == "M_FORBIDDEN"_ls ? PasswordStatus::Wrong : PasswordStatus::Other);
             });
         }
     });
@@ -195,7 +194,7 @@ void NeoChatConnection::createRoom(const QString &name, const QString &topic, co
         });
     }
     connect(job, &CreateRoomJob::failure, this, [job] {
-        Q_EMIT Controller::instance().errorOccured(i18n("Room creation failed: %1", job->errorString()));
+        Q_EMIT Controller::instance().errorOccured(i18n("Room creation failed: %1", job->errorString()), {});
     });
     connectSingleShot(this, &Connection::newRoom, this, [](Room *room) {
         RoomManager::instance().enterRoom(dynamic_cast<NeoChatRoom *>(room));
@@ -227,7 +226,7 @@ void NeoChatConnection::createSpace(const QString &name, const QString &topic, c
         });
     }
     connect(job, &CreateRoomJob::failure, this, [job] {
-        Q_EMIT Controller::instance().errorOccured(i18n("Space creation failed: %1", job->errorString()));
+        Q_EMIT Controller::instance().errorOccured(i18n("Space creation failed: %1", job->errorString()), {});
     });
     connectSingleShot(this, &Connection::newRoom, this, [](Room *room) {
         RoomManager::instance().enterRoom(dynamic_cast<NeoChatRoom *>(room));
