@@ -398,14 +398,6 @@ public:
      */
     [[nodiscard]] const Quotient::RoomEvent *lastEvent() const;
 
-    /**
-     * @brief Convenient way to call eventToString on the last event.
-     *
-     * @sa lastEvent()
-     * @sa eventToString()
-     */
-    [[nodiscard]] QString lastEventToString(Qt::TextFormat format = Qt::PlainText, bool stripNewlines = false) const;
-
     /**
      * @brief Convenient way to check if the last event looks like it has spoilers.
      *
@@ -492,15 +484,6 @@ public:
 
     [[nodiscard]] bool readMarkerLoaded() const;
 
-    /**
-     * @brief Get subtitle text for room
-     *
-     * Fetches last event and removes markdown formatting
-     *
-     * @see lastEventToString()
-     */
-    [[nodiscard]] QString subtitleText();
-
     [[nodiscard]] QString avatarMediaId() const;
 
     Quotient::User *directChatRemoteUser() const;
