@@ -15,6 +15,7 @@
 #include "models/mediamessagefiltermodel.h"
 #include "models/messageeventmodel.h"
 #include "models/messagefiltermodel.h"
+#include "models/timelinemodel.h"
 
 class NeoChatRoom;
 class NeoChatConnection;
@@ -31,6 +32,11 @@ using namespace Quotient;
  * @class RoomManager
  *
  * A singleton class to help manage which room is open in NeoChat.
+ *
+ * This class also inherits UriResolverBase and overrides the relevant functions to
+ * resolve various URIs. The base functions visitUser(), visitRoom(), etc are held
+ * private intentionally and instead resolveResource() should be called with either
+ * an appropriate URI or a Matrix ID and action.
  */
 class RoomManager : public QObject, public UriResolverBase
 {
@@ -48,7 +54,7 @@ class RoomManager : public QObject, public UriResolverBase
     Q_PROPERTY(NeoChatRoom *currentRoom READ currentRoom NOTIFY currentRoomChanged)
 
     /**
-     * @brief The MessageEventModel that should be used for room message visualisation.
+     * @brief The TimelineModel that should be used for room message visualisation.
      *
      * The room object the model uses to get the data will be updated by this class
      * so there is no need to do this manually or replace the model when a room
@@ -57,7 +63,7 @@ class RoomManager : public QObject, public UriResolverBase
      * @note Available here so that the room page and drawer both have access to the
      *       same model.
      */
-    Q_PROPERTY(MessageEventModel *messageEventModel READ messageEventModel CONSTANT)
+    Q_PROPERTY(TimelineModel *timelineModel READ timelineModel CONSTANT)
 
     /**
      * @brief The MessageFilterModel that should be used for room message visualisation.
@@ -101,10 +107,30 @@ public:
 
     NeoChatRoom *currentRoom() const;
 
-    MessageEventModel *messageEventModel() const;
+    TimelineModel *timelineModel() const;
     MessageFilterModel *messageFilterModel() const;
     MediaMessageFilterModel *mediaMessageFilterModel() const;
 
+    /**
+     * @brief Resolve the given URI resource.
+     *
+     * @note It's actually Quotient::UriResolverBase::visitResource() but with Q_INVOKABLE
+     *       and the connection grabbed from RoomManager.
+     *
+     * @sa Quotient::UriResolverBase::visitResource()
+     */
+    Q_INVOKABLE UriResolveResult resolveResource(const Uri &uri);
+
+    /**
+     * @brief Resolve the given resource.
+     *
+     * @note It's actually Quotient::UriResolverBase::visitResource() but with Q_INVOKABLE
+     *       and the connection grabbed from RoomManager.
+     *
+     * @sa Quotient::UriResolverBase::visitResource()
+     */
+    Q_INVOKABLE void resolveResource(const QString &idOrUri, const QString &action = {});
+
     bool hasOpenRoom() const;
 
     /**
@@ -138,56 +164,6 @@ public:
      */
     Q_INVOKABLE void enterSpaceHome(NeoChatRoom *spaceRoom);
 
-    // Overrided methods from UriResolverBase
-    /**
-     * @brief Resolve a user URI.
-     *
-     * This overloads Quotient::UriResolverBase::visitUser().
-     *
-     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
-     * identifies a Matrix user.
-     *
-     * @sa Quotient::UriResolverBase::visitUser(), Quotient::UriResolverBase::visitResource()
-     */
-    Q_INVOKABLE UriResolveResult visitUser(User *user, const QString &action) override;
-
-    /**
-     * @brief Visit a room.
-     *
-     * This overloads Quotient::UriResolverBase::visitRoom().
-     *
-     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
-     * identifies a room or an event in a room.
-     *
-     * @sa Quotient::UriResolverBase::visitRoom(), Quotient::UriResolverBase::visitResource()
-     */
-    Q_INVOKABLE void visitRoom(Quotient::Room *room, const QString &eventId) override;
-
-    /**
-     * @brief Join a room.
-     *
-     * This overloads Quotient::UriResolverBase::joinRoom().
-     *
-     * Called by Quotient::UriResolverBase::visitResource() when the passed URI has
-     * `action() == "join"` and identifies a room that the user defined by the
-     * Connection argument is not a member of.
-     *
-     * @sa Quotient::UriResolverBase::joinRoom(), Quotient::UriResolverBase::visitResource()
-     */
-    void joinRoom(Quotient::Connection *account, const QString &roomAliasOrId, const QStringList &viaServers) override;
-
-    /**
-     * @brief Visit a non-matrix resource.
-     *
-     * This overloads Quotient::UriResolverBase::visitNonMatrix().
-     *
-     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
-     * has `type() == NonMatrix`
-     *
-     * @sa Quotient::UriResolverBase::visitNonMatrix(), Quotient::UriResolverBase::visitResource()
-     */
-    Q_INVOKABLE bool visitNonMatrix(const QUrl &url) override;
-
     /**
      * @brief Knock a room.
      *
@@ -196,16 +172,6 @@ public:
      */
     void knockRoom(Quotient::Connection *account, const QString &roomAliasOrId, const QString &reason, const QStringList &viaServers);
 
-    /**
-     * @brief Open the given resource.
-     *
-     * Convenience function to call Quotient::UriResolverBase::visitResource() from
-     * QML if valid.
-     *
-     * @sa Quotient::UriResolverBase::visitResource()
-     */
-    Q_INVOKABLE void openResource(const QString &idOrUri, const QString &action = {});
-
     /**
      * @brief Show a media item maximized.
      *
@@ -383,8 +349,73 @@ private:
     KConfigGroup m_lastRoomConfig;
     QPointer<ChatDocumentHandler> m_chatDocumentHandler;
 
-    MessageEventModel *m_messageEventModel;
+    TimelineModel *m_timelineModel;
     MessageFilterModel *m_messageFilterModel;
     MediaMessageFilterModel *m_mediaMessageFilterModel;
     NeoChatConnection *m_connection;
+
+    /**
+     * @brief Resolve a user URI.
+     *
+     * This overloads Quotient::UriResolverBase::visitUser().
+     *
+     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
+     * identifies a Matrix user.
+     *
+     * @note This is private as resolveResource() should always be called, which
+     *       will in turn call Quotient::UriResolverBase::visitResource() and this
+     *       function if appropriate for the URI.
+     *
+     * @sa resolveResource(), Quotient::UriResolverBase::visitUser(), Quotient::UriResolverBase::visitResource()
+     */
+    UriResolveResult visitUser(User *user, const QString &action) override;
+
+    /**
+     * @brief Visit a room.
+     *
+     * This overloads Quotient::UriResolverBase::visitRoom().
+     *
+     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
+     * identifies a room or an event in a room.
+     *
+     * @note This is private as resolveResource() should always be called, which
+     *       will in turn call Quotient::UriResolverBase::visitResource() and this
+     *       function if appropriate for the URI.
+     *
+     * @sa resolveResource(), Quotient::UriResolverBase::visitUser(), Quotient::UriResolverBase::visitResource()
+     */
+    Q_INVOKABLE void visitRoom(Quotient::Room *room, const QString &eventId) override;
+
+    /**
+     * @brief Join a room.
+     *
+     * This overloads Quotient::UriResolverBase::joinRoom().
+     *
+     * Called by Quotient::UriResolverBase::visitResource() when the passed URI has
+     * `action() == "join"` and identifies a room that the user defined by the
+     * Connection argument is not a member of.
+     *
+     * @note This is private as resolveResource() should always be called, which
+     *       will in turn call Quotient::UriResolverBase::visitResource() and this
+     *       function if appropriate for the URI.
+     *
+     * @sa resolveResource(), Quotient::UriResolverBase::visitUser(), Quotient::UriResolverBase::visitResource()
+     */
+    void joinRoom(Quotient::Connection *account, const QString &roomAliasOrId, const QStringList &viaServers) override;
+
+    /**
+     * @brief Visit a non-matrix resource.
+     *
+     * This overloads Quotient::UriResolverBase::visitNonMatrix().
+     *
+     * Called by Quotient::UriResolverBase::visitResource() when the passed URI
+     * has `type() == NonMatrix`
+     *
+     * @note This is private as resolveResource() should always be called, which
+     *       will in turn call Quotient::UriResolverBase::visitResource() and this
+     *       function if appropriate for the URI.
+     *
+     * @sa resolveResource(), Quotient::UriResolverBase::visitUser(), Quotient::UriResolverBase::visitResource()
+     */
+    Q_INVOKABLE bool visitNonMatrix(const QUrl &url) override;
 };
