@@ -13,6 +13,7 @@
 #include <KWindowSystem>
 #endif
 
+#include <KSharedConfig>
 #include <QStandardPaths>
 
 WindowController &WindowController::instance()
@@ -35,24 +36,29 @@ QWindow *WindowController::window() const
 
 void WindowController::restoreGeometry()
 {
-    KConfig dataResource("data", KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup windowGroup(&dataResource, "Window");
+    const auto stateConfig = KSharedConfig::openStateConfig();
+    const KConfigGroup windowGroup = stateConfig->group(QStringLiteral("Window"));
+
     KWindowConfig::restoreWindowSize(m_window, windowGroup);
     KWindowConfig::restoreWindowPosition(m_window, windowGroup);
 }
 
 void WindowController::saveGeometry()
 {
-    KConfig dataResource("data", KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup windowGroup(&dataResource, "Window");
+    const auto stateConfig = KSharedConfig::openStateConfig();
+    KConfigGroup windowGroup = stateConfig->group(QStringLiteral("Window"));
+
     KWindowConfig::saveWindowPosition(m_window, windowGroup);
     KWindowConfig::saveWindowSize(m_window, windowGroup);
+
+    stateConfig->sync();
 }
 
 void WindowController::showAndRaiseWindow(const QString &startupId)
 {
     if (!m_window->isVisible()) {
         m_window->show();
+        restoreGeometry();
     }
 
 #ifdef HAVE_WINDOWSYSTEM
@@ -70,4 +76,30 @@ void WindowController::showAndRaiseWindow(const QString &startupId)
 #endif
 }
 
+bool WindowController::hasWindowSystem() const
+{
+#ifdef HAVE_WINDOWSYSTEM
+    return true;
+#else
+    return false;
+#endif
+}
+
+void WindowController::setBlur(QQuickItem *item, bool blur)
+{
+#ifdef HAVE_WINDOWSYSTEM
+    auto setWindows = [item, blur]() {
+        auto reg = QRect(QPoint(0, 0), item->window()->size());
+        KWindowEffects::enableBackgroundContrast(item->window(), blur, 1, 1, 1, reg);
+        KWindowEffects::enableBlurBehind(item->window(), blur, reg);
+    };
+
+    disconnect(item->window(), &QQuickWindow::heightChanged, this, nullptr);
+    disconnect(item->window(), &QQuickWindow::widthChanged, this, nullptr);
+    connect(item->window(), &QQuickWindow::heightChanged, this, setWindows);
+    connect(item->window(), &QQuickWindow::widthChanged, this, setWindows);
+    setWindows();
+#endif
+}
+
 #include "moc_windowcontroller.cpp"
